@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Optional
 
 import jmespath
 
@@ -9,11 +9,13 @@ class JMESPathSearch(KeyQuery):
     def _parse(
         self,
         data: Any,
+        query: Optional[str],
     ):
 
-        data = jmespath.search(
-            expression=self._query,
-            data=data,
-        )
+        if query:
+            data = jmespath.search(
+                expression=query,
+                data=data,
+            )
 
         return self._process_data_key_values(data)
